import functools

__version_info__ = ('0', '0', '1')
__version__ = '.'.join(__version_info__)


def memoize(func):
    cache = {}

    @functools.wraps(func)
    def memoized(*args):
        try:
            return cache[args]
        except KeyError:
            cache[args] = func(*args)
            return cache[args]
    return memoized



from distutils.core import setup

from memoizer import __version__


setup(
    name="memoizer",
    version=__version__,
    description="portable way to memoize functions",
    author="Ceasar Bautista",
    author_email="cbautista2010@gmail.com",
    url="https://github.com/Ceasar/memoizer",
    keywords=["memoize"],
    py_modules=['memoizer'],
    classifiers=[
    "Intended Audience :: Developers",
    "License :: OSI Approved :: MIT License",
    "Operating System :: OS Independent",
    "Programming Language :: Python",
    "Programming Language :: Python :: 2.5",
    "Programming Language :: Python :: 2.6",
    "Programming Language :: Python :: 2.7",
    "Topic :: Software Development :: Libraries :: Python Modules",
    "Development Status :: 4 - Beta",
    "Intended Audience :: Developers",
    ],
)
